// components/player/player.js
const _windowWidth = wx.getSystemInfoSync().windowWidth

Component({
  /**
   * 组件的属性列表
   */
  properties: {
    //  组件的pubID
    pubID: {
      type: String,
      value: ""
    },
    //  组件显示区域的宽度
    width: {
      type: Number,
      value: _windowWidth
    },
    //  组件显示区域的高度
    height: {
      type: Number,
      value: 0,
    },
    enableAudio: {
      type: Boolean,
      value: true
    },
    playURL: {
      type: String,
      value: ""
    }
  },

  ready () {
    this.setData({
      playerContext: wx.createLivePlayerContext(this.data.pubID, this)
    });
  },

  /**
   * 组件的初始数据
   */
  data: {
    playerContext: null
  },

  /**
   * 组件的方法列表
   */
  methods: {
    onPlay (e) {
      this.triggerEvent('playStatus', {
        pubID: e.currentTarget.id,
        code: e.detail.code
      }, {});
    },

    //暂停 参考 https://developers.weixin.qq.com/miniprogram/dev/api/media/live/LivePlayerContext.pause.html
    pause (obj) {
      this.data.playerContext || (wx.createLivePlayerContext(this.data.pubID, this));

      this.data.playerContext.pause(obj);
    },

    //播放 参考 https://developers.weixin.qq.com/miniprogram/dev/api/media/live/LivePlayerContext.play.html
    play (obj) {
      this.data.playerContext || (wx.createLivePlayerContext(this.data.pubID, this));

      this.data.playerContext.play(obj);
    },

    //禁音 参考 https://developers.weixin.qq.com/miniprogram/dev/api/media/live/LivePlayerContext.mute.html
    mute (obj) {
      this.data.playerContext || (wx.createLivePlayerContext(this.data.pubID, this));

      this.data.playerContext.mute(obj);
    },

    //全屏 参考https://developers.weixin.qq.com/miniprogram/dev/api/media/live/LivePlayerContext.requestFullScreen.html
    requestFullScreen (obj) {
      this.data.playerContext || (wx.createLivePlayerContext(this.data.pubID, this));

      this.data.playerContext.requestFullScreen(obj);
    },
    //退出全屏 参考https://developers.weixin.qq.com/miniprogram/dev/api/media/live/LivePlayerContext.exitFullScreen.html
    exitFullScreen (obj) {
      this.data.playerContext || (wx.createLivePlayerContext(this.data.pubID, this));

      this.data.playerContext.exitFullScreen(obj);
    }
  }
})
